@@ -7,10 +7,10 @@ use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw( flatten parse format random );
-our @EXPORT = qw( test );
+our @EXPORT_OK = qw( canon_id parse_id format_id random_id );
+our @EXPORT = qw( test_id );
 
-our $VERSION = '0.00_08';
+our $VERSION = '0.00_13';
 
 use Carp;
 
@@ -19,6 +19,7 @@ my %types = (
   cpf => 'Business::BR::CPF',
   cnpj => 'Business::BR::CNPJ',
   ie => 'Business::BR::IE',
+  pis => 'Business::BR::PIS',
 );
 
 
@@ -33,24 +34,23 @@ sub _invoke {
 	return &{"${package}::${subroot}${type}"}(@_);
 }
 
-sub test {
+sub test_id {
 	return _invoke(shift, 'test_', @_);
 }
 
-sub flatten {
-	return _invoke(shift, 'flatten_', @_);
+sub canon_id {
+	return _invoke(shift, 'canon_', @_);
 }
 
-# PROBLEM: format is builtin - needs a work around
-#sub format {
-#	return _invoke(shift, 'format_', @_);
-#}
+sub format_id {
+	return _invoke(shift, 'format_', @_);
+}
 
-sub parse {
+sub parse_id {
 	return _invoke(shift, 'parse_', @_);
 }
 
-sub random {
+sub random_id {
 	return _invoke(shift, 'random_', @_);
 }
 
@@ -66,40 +66,51 @@ Business::BR::Ids - Modules for dealing with Brazilian identification codes (CPF
 
   use Business::BR::Ids;
   my $cpf = '390.533.447-05';
-  print "ok as CPF" if test('cpf', $cpf);
+  print "ok as CPF" if test_id('cpf', $cpf);
   my $cnpj = '90.117.749/7654-80';
-  print "ok as CNPJ" if test('cnpj', $cnpj);
+  print "ok as CNPJ" if test_id('cnpj', $cnpj);
 
 =head1 DESCRIPTION
 
 This is a generic module for handling the various supported
 operations on Brazilian identification numbers and codes.
-For example, it is capable to test the correctness of CPF
-and CNPJ numbers without the need for explicitly 'requiring' or
+For example, it is capable to test the correctness of CPF,
+CNPJ and IE numbers without the need for explicitly 'requiring' or
 'using' this modules (doing it automatically on demand).
 
 =over 4
 
-=item B<test>
+=item B<test_id>
 
-  test($entity_type, @args); 
-  test('cpf', $cpf); # the same as "require Business::BR::CPF; Business::BR::CPF::test_cpf($cpf)"
+  test_id($entity_type, @args); 
+  test_id('cpf', $cpf); # the same as "require Business::BR::CPF; Business::BR::CPF::test_cpf($cpf)"
 
 Tests for correct inputs of ids which have a corresponding Business::BR module.
-For now, the supported id types are 'cpf' and 'cnpj'.
+For now, the supported id types are 'cpf', 'cnpj', 'ie', and 'pis'.
 
+=item B<canon_id>
 
+  canon_id($entity_type, @args)
+
+Transform the input to a canonical form. The canonical
+form is well-defined and as short as possible.
+For instance, C<canon_id('cpf', '29.128.129-11')>
+returns C<'02912812911'> which has exactly 11 digits
+and no extra character.
+
+=back
 
 =head2 EXPORT
 
-C<test> is exported by default. 
+C<test_id> is exported by default. C<canon_id>, C<format_id>,
+C<parse_id> and C<random_id> are exported on demand.
 
 =begin comment
 
  =head1 OVERVIEW
 
  test_*
- flatten_*
+ canon_*
  format_*
  parse_*
  random_*
@@ -137,6 +148,29 @@ C<test> is exported by default.
 
 =head1 SEE ALSO
 
+Details on handling CPF, CNPJ, IE and PIS can be found in
+the specific modules:
+
+=over 4
+
+=item *
+
+Business::BR::CPF
+
+=item *
+
+Business::BR::CNPJ
+
+=item *
+
+Business::BR::IE
+
+=item *
+
+Business::BR::PIS
+
+=back
+
 Please reports bugs via CPAN RT, 
 http://rt.cpan.org/NoAuth/Bugs.html?Dist=Business-BR-Ids
 
